﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using WpfTestingSample.Model;

namespace WpfTestingSample
{
    public static class DataTableExtensions
    {
        public static ObservableCollection<dynamic> ToDynamic(this DataTable dt)
        {
            var dynamicDt = new ObservableCollection<dynamic>();
            foreach (System.Data.DataRow row in dt.Rows)
            {
                dynamic dyn = new ExpandoObject();
                dynamicDt.Add(dyn);
                foreach (System.Data.DataColumn column in dt.Columns)
                {
                    var dic = (IDictionary<string, object>)dyn;
                    dic[column.ColumnName] = row[column];
                }
            }
            return dynamicDt;
        }
    }

    class ViewModel:INotifyPropertyChanged
    {
        #region Constructor

        public ViewModel()
        {
            this.DTSource = new EmployeeDetails();
            this.EmployeeCollection = DataTableExtensions.ToDynamic(this.DTSource);
            companies = new ObservableCollection<CompanyItem>()
                {
                new CompanyItem() { CountryCode = "1", CountryName = "NAURU" },
                new CompanyItem() { CountryCode = "2", CountryName = "NEPAL" },
                new CompanyItem() { CountryCode = "3", CountryName = "NETHERLANDS" },
                new CompanyItem() { CountryCode = "4", CountryName = "NEW ZEALAND" },
                new CompanyItem() { CountryCode = "5", CountryName = "US" },
                new CompanyItem() { CountryCode = "6", CountryName = "NIGER" },
                new CompanyItem() { CountryCode = "7", CountryName = "NIGERIA" },
                new CompanyItem() { CountryCode = "8", CountryName = "NIUE" }  
                };
        }

        #endregion

        ObservableCollection<dynamic> _employeeCollection;
        public ObservableCollection<dynamic> EmployeeCollection
        {
            get { return _employeeCollection; }
            set { _employeeCollection = value;
                this.OnPropertyChanged("EmployeeCollection");
            }
        }
        public DataTable DTSource { get; set; }

        private ObservableCollection<CompanyItem> companies;
        public ObservableCollection<CompanyItem> Companies
        {
            get { return companies; }
            set { companies = value; }
        }

        #region INotifyPropertyChanged Members
        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

    }

    class EmployeeDetails : DataTable
    {
        Random rand = new Random();
        public EmployeeDetails()
        {
            PopulateCollection();
        }

        private void PopulateCollection()
        {
            this.Clear();
            this.Columns.Clear();

            this.Columns.Add(new DataColumn("EmployeeName"));
            this.Columns.Add(new DataColumn("CountryCode"));
            this.Columns.Add(new DataColumn("EmployeeAge", typeof(int)));
            this.Columns.Add(new DataColumn("EmployeeArea"));
            this.Columns.Add(new DataColumn("EmployeeSalary", typeof(double)));
            this.Columns.Add(new DataColumn("ExperienceInMonth", typeof(int)));
            this.Columns.Add(new DataColumn("EmployeeGender"));
            this.Columns.Add(new DataColumn("EmployeeDate", typeof(DateTime)));

            var row = this.NewRow();
            row[0] = "Mart";row[1] = "5";row[2] = 1;row[3] = "101010";row[4] = 1.7;row[5] = 10;row[6] = "Male";row[7] = DateTime.Now;
            this.Rows.Add(row);

            row = this.NewRow();
            row[0] = "Peter"; row[1] = "1"; row[2] = 1; row[3] = "010101"; row[4] = 2.5; row[5] = 10; row[6] = "Male"; row[7] = DateTime.Now;
            this.Rows.Add(row);

            row = this.NewRow();
            row[0] = "James"; row[1] = "3"; row[2] = 1; row[3] = "010101"; row[4] = 2.5; row[5] = 10; row[6] = "Male"; row[7] = DateTime.Now;
            this.Rows.Add(row);

            row = this.NewRow();
            row[0] = "Oliver"; row[1] = "5"; row[2] = 1; row[3] = "010101"; row[4] = 2.5; row[5] = 10; row[6] = "Male"; row[7] = DateTime.Now;
            this.Rows.Add(row);

            row = this.NewRow();
            row[0] = "Robert"; row[1] = "2"; row[2] = 1; row[3] = "010101"; row[4] = 2.5; row[5] = 10; row[6] = "Male"; row[7] = DateTime.Now;
            this.Rows.Add(row);

            row = this.NewRow();
            row[0] = "Suji"; row[1] = "1"; row[2] = 1; row[3] = "010101"; row[4] = 2.5; row[5] = 10; row[6] = "Male"; row[7] = DateTime.Now;
            this.Rows.Add(row);

            row = this.NewRow();
            row[0] = "Mahesh"; row[1] = "4"; row[2] = 1; row[3] = "010101"; row[4] = 2.5; row[5] = 10; row[6] = "Male"; row[7] = DateTime.Now;
            this.Rows.Add(row);
        }
    }

    class CompanyItem:INotifyPropertyChanged
    {
        private string _countryCode;
        public string CountryCode
        {
            get
            {
                return _countryCode;
            }
            set
            {
                _countryCode = value;
                OnPropertyChanged("CountryCode");
            }
        }

        private string _countryName;
        public string CountryName
        {
            get
            {
                return _countryName;
            }
            set
            {
                _countryName = value;
                OnPropertyChanged("CountryName");
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion
    }

}
